@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from platformdirs import PlatformDirs, __version__
 
 PROPS = (
@@ -7,9 +9,11 @@ PROPS = (
     "user_state_dir",
     "user_log_dir",
     "user_documents_dir",
+    "user_pictures_dir",
     "user_runtime_dir",
     "site_data_dir",
     "site_config_dir",
+    "site_cache_dir",
 )
 
 
